<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-safehtml?lang_cible=pt_br
// ** ne pas modifier le fichier **

return [

	// S
	'safehtml_description' => 'Proteção dos foruns contra ataques do tipo cross-site scripting',
	'safehtml_slogan' => 'Proteção dos foruns contra cross-site scripting',
];
